@@ -15,8 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <stdlib.h>
-
 #include <qlayout.h>
 #include <qtimer.h>
 
@@ -27,17 +25,20 @@
 #include <kstandarddirs.h>
 #include <kstatusbar.h>
 #include <kstdgameaction.h>
+#include <kcmdlineargs.h>
+#include <kmessagebox.h>
+#include <kuser.h>
 
 #include <kscoredialog.h>
 
+
 #include "kbattleship.moc"
 
 extern const char *clientVersion;
 
-KBattleshipApp::KBattleshipApp() : KMainWindow()
+KBattleshipWindow::KBattleshipWindow() : KMainWindow()
 {
 	shift = false;
-	setMinimumSize(750, 500);
 	m_connection = 0;
 	m_lost = 0;
 	m_config = 0;
@@ -46,18 +47,10 @@ KBattleshipApp::KBattleshipApp() : KMainWindow()
 	m_aiPlayer = 0;
 	m_aiHits = 0;
 
-	QString picDirCheck = locate("data", "kbattleship/pictures/");
-	QString onePicCheck = locate("data", "kbattleship/pictures/hit.png");
-	if(picDirCheck.isEmpty() || onePicCheck.isEmpty())
-	{
-		KMessageBox::error(this, i18n("You don't have KBattleship pictures installed. The game cannot run without them!"));
-		exit(0);
-	}
-	else
-		init();
+	init();
 }
 
-KBattleshipApp::~KBattleshipApp()
+KBattleshipWindow::~KBattleshipWindow()
 {
 	if(m_config != 0)
 		saveOptions();
@@ -66,7 +59,7 @@ KBattleshipApp::~KBattleshipApp()
 	delete m_enemyshiplist;
 }
 
-void KBattleshipApp::init()
+void KBattleshipWindow::init()
 {
 	m_aiPlaying = false;
 	m_placeable = false;
@@ -74,21 +67,20 @@ void KBattleshipApp::init()
 	m_serverHasClient = false;
 	m_config = kapp->config();
 	initStatusBar();
-	// TODO fix screen in 800x600!!!
-	resize(850, 600);
 	initActions();
 	readOptions();
 	initView();
 	initChat();
 	initShipPlacing();
+	parseCommandLine();
 }
 
-void KBattleshipApp::slotConfigureNotifications()
+void KBattleshipWindow::slotConfigureNotifications()
 {
   KNotifyDialog::configure(this);
 }
 
-void KBattleshipApp::initStatusBar()
+void KBattleshipWindow::initStatusBar()
 {
 	m_ownNickname = "-";
 	m_enemyNickname = "-";
@@ -98,7 +90,7 @@ void KBattleshipApp::initStatusBar()
 	statusBar()->setItemAlignment(ID_STATUS_MSG, AlignLeft);
 }
 
-void KBattleshipApp::initActions()
+void KBattleshipWindow::initActions()
 {
 	KStdAction::configureNotifications(this, SLOT(slotConfigureNotifications()), actionCollection());
 	m_gameServerConnect = new KAction(i18n("&Connect to Server..."), "connect_no", Key_F2, this, SLOT(slotServerConnect()), actionCollection(), "game_serverconnect");
@@ -117,24 +109,24 @@ void KBattleshipApp::initActions()
 	setupGUI( KMainWindow::Save | StatusBar | Keys | Create );
 }
 
-void KBattleshipApp::initChat()
+void KBattleshipWindow::initChat()
 {
 	connect(m_chat, SIGNAL(sigSendMessage(const QString &)), this, SLOT(slotSendChatMessage(const QString &)));
 	connect(m_chat, SIGNAL(sigChangeEnemyNickname(const QString &)), this, SLOT(slotChangeEnemyPlayer(const QString &)));
 	connect(m_chat, SIGNAL(sigChangeOwnNickname(const QString &)), this, SLOT(slotChangedNickCommand(const QString &)));
 }
 
-void KBattleshipApp::changeShipPlacementDirection(){
+void KBattleshipWindow::changeShipPlacementDirection(){
   shift = !shift;
 }
 
-void KBattleshipApp::initShipPlacing()
+void KBattleshipWindow::initShipPlacing()
 {
 	connect(m_ownshiplist, SIGNAL(sigOwnFieldDataChanged(int, int, int)), this, SLOT(slotChangeOwnFieldData(int, int, int)));
 	connect(m_ownshiplist, SIGNAL(sigLastShipAdded()), this, SLOT(slotShipsReady()));
 }
 
-void KBattleshipApp::initView()
+void KBattleshipWindow::initView()
 {
 	QWidget *dummy = new QWidget(this, "dummy");
 	setCentralWidget(dummy);
@@ -160,23 +152,22 @@ void KBattleshipApp::initView()
 	connect(m_view, SIGNAL(sigOwnFieldClicked(int, int)), this, SLOT(slotPlaceShip(int, int)));
 	connect(m_view, SIGNAL(sigMouseOverField(int, int)), this, SLOT(slotPlaceShipPreview(int, int)));
 	connect(m_view, SIGNAL(changeShipPlacementDirection()), this, SLOT(changeShipPlacementDirection()));
-	setCaption(i18n("KBattleship %1").arg(clientVersion), false);
 }
 
-void KBattleshipApp::slotDeleteAI()
+void KBattleshipWindow::slotDeleteAI()
 {
 	m_aiHits = 0;
 	delete m_aiPlayer;
 	m_aiPlayer = 0;
 }
 
-void KBattleshipApp::slotRestartAI()
+void KBattleshipWindow::slotRestartAI()
 {
 	m_aiHits = 0;
 	slotStartBattleshipGame(false);
 }
 
-void KBattleshipApp::slotEnemyFieldClick(int fieldx, int fieldy)
+void KBattleshipWindow::slotEnemyFieldClick(int fieldx, int fieldy)
 {
 	if(m_connection != 0 || m_aiPlaying)
 	{
@@ -267,7 +258,7 @@ void KBattleshipApp::slotEnemyFieldClick(int fieldx, int fieldy)
 					if(xokay)
 					{
 						DeathValueList::Iterator it;
-						for(it = deathList.begin(); it != deathList.end(); it++)
+						for(it = deathList.begin(); it != deathList.end(); ++it)
 						{
 							if(fieldy+1 < m_enemyshiplist->m_fieldy) m_view->changeEnemyFieldData(*it, fieldy+1, KBattleField::BORDER);
 							m_view->changeEnemyFieldData(*it, fieldy, KBattleField::DEATH);
@@ -289,7 +280,7 @@ void KBattleshipApp::slotEnemyFieldClick(int fieldx, int fieldy)
 					else if(yokay)
 					{
 						DeathValueList::Iterator it;
-						for(it = deathList.begin(); it != deathList.end(); it++)
+						for(it = deathList.begin(); it != deathList.end(); ++it)
 						{
 							if (fieldx>0) m_view->changeEnemyFieldData(fieldx-1, *it, KBattleField::BORDER);
 							m_view->changeEnemyFieldData(fieldx, *it, KBattleField::DEATH);
@@ -323,7 +314,7 @@ void KBattleshipApp::slotEnemyFieldClick(int fieldx, int fieldy)
 				slotStatusMsg(i18n("You won the game :)"));
 				m_stat->slotAddOwnWon();
 				slotUpdateHighscore();
-				switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?")))
+				switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?"),QString::null,i18n("Restart"),i18n("Do Not Restart")))
 				{
 					case KMessageBox::Yes:
 						QTimer::singleShot(0, this, SLOT(slotRestartAI()));
@@ -341,7 +332,7 @@ void KBattleshipApp::slotEnemyFieldClick(int fieldx, int fieldy)
 	}
 }
 
-void KBattleshipApp::slotReceivedEnemyFieldData(int fieldx, int fieldy, int enemystate, int xstart, int xstop, int ystart, int ystop, bool death)
+void KBattleshipWindow::slotReceivedEnemyFieldData(int fieldx, int fieldy, int enemystate, int xstart, int xstop, int ystart, int ystop, bool death)
 {
 	m_stat->setShot();
 
@@ -422,19 +413,19 @@ void KBattleshipApp::slotReceivedEnemyFieldData(int fieldx, int fieldy, int enem
 	}
 }
 
-void KBattleshipApp::slotClientLost()
+void KBattleshipWindow::slotClientLost()
 {
 	slotAbortNetworkGame();
 	slotStatusMsg(i18n("Enemy disconnected."));
 }
 
-void KBattleshipApp::slotServerLost()
+void KBattleshipWindow::slotServerLost()
 {
 	slotAbortNetworkGame();
 	slotStatusMsg(i18n("Enemy disconnected."));
 }
 
-void KBattleshipApp::slotAbortNetworkGame()
+void KBattleshipWindow::slotAbortNetworkGame()
 {
 	slotStatusMsg(i18n("Ready"));
 	slotChangeOwnPlayer("-");
@@ -472,7 +463,7 @@ void KBattleshipApp::slotAbortNetworkGame()
 	}
 }
 
-void KBattleshipApp::slotReplay()
+void KBattleshipWindow::slotReplay()
 {
 	cleanup(true);
 	m_aiPlaying = false;
@@ -485,7 +476,7 @@ void KBattleshipApp::slotReplay()
 	m_stat->clear();
 }
 
-void KBattleshipApp::slotPlaceShipPreview(int fieldx, int fieldy)
+void KBattleshipWindow::slotPlaceShipPreview(int fieldx, int fieldy)
 {
 	int xadd = 0, yadd = 0;
 
@@ -544,7 +535,7 @@ void KBattleshipApp::slotPlaceShipPreview(int fieldx, int fieldy)
 	}
 }
 
-void KBattleshipApp::slotPlaceShip(int fieldx, int fieldy)
+void KBattleshipWindow::slotPlaceShip(int fieldx, int fieldy)
 {
 	if(m_connection != 0 || m_aiPlaying)
 	{
@@ -559,7 +550,7 @@ void KBattleshipApp::slotPlaceShip(int fieldx, int fieldy)
 	}
 }
 
-void KBattleshipApp::slotShipsReady()
+void KBattleshipWindow::slotShipsReady()
 {
 	if(m_aiPlaying)
 	{
@@ -580,7 +571,7 @@ void KBattleshipApp::slotShipsReady()
 	m_placeable = false;
 }
 
-void KBattleshipApp::slotSendMessage(int fieldx, int fieldy, int state)
+void KBattleshipWindow::slotSendMessage(int fieldx, int fieldy, int state)
 {
 	if(m_connection != 0)
 	{
@@ -596,7 +587,7 @@ void KBattleshipApp::slotSendMessage(int fieldx, int fieldy, int state)
 	}
 }
 
-void KBattleshipApp::slotSendMessage(KMessage *msg)
+void KBattleshipWindow::slotSendMessage(KMessage *msg)
 {
 	if(m_connection != 0)
 	{
@@ -607,7 +598,7 @@ void KBattleshipApp::slotSendMessage(KMessage *msg)
 	}
 }
 
-void KBattleshipApp::slotSendChatMessage(const QString &text)
+void KBattleshipWindow::slotSendChatMessage(const QString &text)
 {
 	if(m_connection != 0 && m_serverHasClient)
 	{
@@ -617,24 +608,24 @@ void KBattleshipApp::slotSendChatMessage(const QString &text)
 	}
 }
 
-void KBattleshipApp::slotChangedNickCommand(const QString &text)
+void KBattleshipWindow::slotChangedNickCommand(const QString &text)
 {
 	m_ownNickname = text;
 	slotChangeOwnPlayer(m_ownNickname);
 	m_chat->setNickname(m_ownNickname);
 }
 
-KShip *KBattleshipApp::shipAt(int fieldx, int fieldy)
+KShip *KBattleshipWindow::shipAt(int fieldx, int fieldy)
 {
 	return m_ownshiplist->shipAt(fieldx, fieldy);
 }
 
-KShip *KBattleshipApp::enemyShipAt(int fieldx, int fieldy)
+KShip *KBattleshipWindow::enemyShipAt(int fieldx, int fieldy)
 {
 	return m_enemyshiplist->shipAt(fieldx, fieldy);
 }
 
-void KBattleshipApp::slotUpdateHighscore()
+void KBattleshipWindow::slotUpdateHighscore()
 {
 	// Balancing factors
 	// a = shot-balance
@@ -658,7 +649,7 @@ void KBattleshipApp::slotUpdateHighscore()
 	scoreDialog->addScore((int)score, info, false, false);
 }
 
-void KBattleshipApp::saveOptions()
+void KBattleshipWindow::saveOptions()
 {
 	m_config->setGroup("General");
 	m_config->writeEntry("PlaySounds", m_configSound->isChecked());
@@ -666,14 +657,14 @@ void KBattleshipApp::saveOptions()
 	m_config->sync();
 }
 
-void KBattleshipApp::readOptions()
+void KBattleshipWindow::readOptions()
 {
 	m_config->setGroup("General");
 	m_configSound->setChecked(m_config->readBoolEntry("PlaySounds", true));
 	m_configGrid->setChecked(m_config->readBoolEntry("ShowGrid", false));
 }
 
-void KBattleshipApp::slotHighscore()
+void KBattleshipWindow::slotHighscore()
 {
 	KScoreDialog *scoreDialog = new KScoreDialog(KScoreDialog::Name | KScoreDialog::Score | KScoreDialog::Custom1 | KScoreDialog::Custom2 | KScoreDialog::Custom3, this);
 	scoreDialog->addField(KScoreDialog::Custom1, i18n("Shots"), "shots");
@@ -682,7 +673,7 @@ void KBattleshipApp::slotHighscore()
 	scoreDialog->show();
 }
 
-void KBattleshipApp::slotEnemyClientInfo()
+void KBattleshipWindow::slotEnemyClientInfo()
 {
 	KInfoDialog *m_info = new KInfoDialog(this);
 
@@ -694,16 +685,18 @@ void KBattleshipApp::slotEnemyClientInfo()
 	m_info->show();
 }
 
-void KBattleshipApp::slotServerConnect()
+void KBattleshipWindow::slotServerConnect()
 {
 	if(m_connection == 0)
 	{
-		if(m_client != 0)
+		if(m_client != 0) {
+			m_client->show();
 			return;
+		}
 
 		slotStatusMsg(i18n("Loading Connect-Server dialog..."));
 
-		m_client = new KClientDialog();
+		m_client = new KClientDialog(this);
 		connect(m_client, SIGNAL(sigConnectServer()), this, SLOT(slotConnectToBattleshipServer()));
 		connect(m_client, SIGNAL(sigCancelConnect()), this, SLOT(slotDeleteConnectDialog()));
 		m_client->show();
@@ -714,15 +707,15 @@ void KBattleshipApp::slotServerConnect()
 		slotAbortNetworkGame();
 }
 
-void KBattleshipApp::slotDeleteConnectDialog()
+void KBattleshipWindow::slotDeleteConnectDialog()
 {
 	delete m_client;
 	m_client = 0;
 }
 
-void KBattleshipApp::slotReplayRequest()
+void KBattleshipWindow::slotReplayRequest()
 {
-	switch(KMessageBox::questionYesNo(this, i18n("The client is asking to restart the game. Do you accept?")))
+	switch(KMessageBox::questionYesNo(this, i18n("The client is asking to restart the game. Do you accept?"),QString::null,i18n("Accept Restart"), i18n("Deny Restart")))
 	{
 		case KMessageBox::Yes:
 			if (m_connection)
@@ -739,10 +732,10 @@ void KBattleshipApp::slotReplayRequest()
 	}
 }
 
-void KBattleshipApp::slotServerReplay()
+void KBattleshipWindow::slotServerReplay()
 {
 	KMessage *msg = new KMessage(KMessage::REPLAY);
-	switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?")))
+	switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?"), QString::null, i18n("Restart"), i18n("Do Not Restart")))
 	{
 		case KMessageBox::Yes:
 			if (m_connection)
@@ -765,10 +758,10 @@ void KBattleshipApp::slotServerReplay()
 	}
 }
 
-void KBattleshipApp::slotClientReplay()
+void KBattleshipWindow::slotClientReplay()
 {
 	KMessage *msg = new KMessage(KMessage::REPLAY);
-	switch(KMessageBox::questionYesNo(this, i18n("Do you want to ask the server restarting the game?")))
+	switch(KMessageBox::questionYesNo(this, i18n("Do you want to ask the server restarting the game?"), QString::null, i18n("Ask to Restart"), i18n("Do Not Ask")))
 	{
 		case KMessageBox::Yes:
 			if (m_connection)
@@ -791,7 +784,7 @@ void KBattleshipApp::slotClientReplay()
 	}
 }
 
-void KBattleshipApp::cleanup(bool placechange)
+void KBattleshipWindow::cleanup(bool placechange)
 {
 	if(placechange)
 		m_placeable = false;
@@ -803,7 +796,7 @@ void KBattleshipApp::cleanup(bool placechange)
 	m_view->field()->drawField();
 }
 
-void KBattleshipApp::slotNewServer()
+void KBattleshipWindow::slotNewServer()
 {
 	if(m_connection == 0)
 	{
@@ -812,9 +805,9 @@ void KBattleshipApp::slotNewServer()
 
 		slotStatusMsg(i18n("Loading Start-Server dialog..."));
 
-		m_server = new KServerDialog();
-		connect(m_server, SIGNAL(sigStartServer()), this, SLOT(slotStartBattleshipServer()));
-		connect(m_server, SIGNAL(sigCancelServer()), this, SLOT(slotDeleteServerDialog()));
+		m_server = new KServerDialog(this);
+		connect(m_server, SIGNAL(okClicked()), this, SLOT(slotStartBattleshipServer()));
+		connect(m_server, SIGNAL(cancelClicked()), this, SLOT(slotDeleteServerDialog()));
 		m_server->show();
 
 		slotStatusMsg(i18n("Ready"));
@@ -823,13 +816,13 @@ void KBattleshipApp::slotNewServer()
 		slotAbortNetworkGame();
 }
 
-void KBattleshipApp::slotDeleteServerDialog()
+void KBattleshipWindow::slotDeleteServerDialog()
 {
 	delete m_server;
 	m_server = 0;
 }
 
-void KBattleshipApp::slotSendVersion()
+void KBattleshipWindow::slotSendVersion()
 {
 	KMessage *msg = new KMessage(KMessage::GETVERSION);
 	msg->versionMessage();
@@ -838,7 +831,7 @@ void KBattleshipApp::slotSendVersion()
 	QTimer::singleShot(150, this, SLOT(slotSendGreet()));
 }
 
-void KBattleshipApp::slotSendGreet()
+void KBattleshipWindow::slotSendGreet()
 {
 	m_serverHasClient = true;
 	m_chat->slotAcceptMsg(true);
@@ -848,13 +841,13 @@ void KBattleshipApp::slotSendGreet()
 	slotSendMessage(msg);
 }
 
-void KBattleshipApp::slotStartBattleshipServer()
+void KBattleshipWindow::slotStartBattleshipServer()
 {
 	m_gameNewServer->setText(i18n("&Stop server"));
 	m_gameServerConnect->setEnabled(false);
 	m_gameSingle->setEnabled(false);
 	slotStatusMsg(i18n("Waiting for a player..."));
-	m_kbserver = new KBattleshipServer((m_server->port()).toInt());
+	m_kbserver = new KBattleshipServer((m_server->port()).toInt(),m_server->gamename());
 	m_ownNickname = m_server->nickname();
 	m_chat->setNickname(m_ownNickname);
 	slotChangeOwnPlayer(m_ownNickname);
@@ -919,14 +912,14 @@ void KBattleshipApp::slotStartBattleshipServer()
 	m_kbserver->init();
 }
 
-void KBattleshipApp::slotLost(KMessage *msg)
+void KBattleshipWindow::slotLost(KMessage *msg)
 {
 	m_stat->slotAddEnemyWon();
-	if (msg->field("ship0") != QString::null) m_view->drawEnemyShipsHuman(msg, m_enemyshiplist);
+	if (!msg->field("ship0").isNull()) m_view->drawEnemyShipsHuman(msg, m_enemyshiplist);
 	m_lost = true;
 }
 
-void KBattleshipApp::slotSendEnemyFieldState(int fieldx, int fieldy)
+void KBattleshipWindow::slotSendEnemyFieldState(int fieldx, int fieldy)
 {
 	int data, showstate;
 	bool xokay = false, yokay = false;
@@ -1024,13 +1017,13 @@ void KBattleshipApp::slotSendEnemyFieldState(int fieldx, int fieldy)
 		m_kbclient->sendMessage(msg);
 }
 
-void KBattleshipApp::slotChangeOwnFieldData(int fieldx, int fieldy, int type)
+void KBattleshipWindow::slotChangeOwnFieldData(int fieldx, int fieldy, int type)
 {
 	m_view->changeOwnFieldData(fieldx, fieldy, type);
 	playSound(true, type);
 }
 
-void KBattleshipApp::playSound(bool enemy, int fieldstate)
+void KBattleshipWindow::playSound(bool enemy, int fieldstate)
 {
 	if (m_configSound->isChecked())
 	{
@@ -1054,20 +1047,54 @@ void KBattleshipApp::playSound(bool enemy, int fieldstate)
 	}
 }
 
-void KBattleshipApp::slotChangeEnemyFieldData(int fieldx, int fieldy, int type)
+void KBattleshipWindow::slotChangeEnemyFieldData(int fieldx, int fieldy, int type)
 {
 	m_view->changeEnemyFieldData(fieldx, fieldy, type);
 	playSound(false, type);
 }
 
-void KBattleshipApp::slotConnectToBattleshipServer()
+void KBattleshipWindow::parseCommandLine() {
+	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+        if ( args->count() > 0 )
+	{
+		KURL u( args->url(0));
+		if(u.protocol().isEmpty())
+			u.setProtocol("kbattleship");
+		if( !u.isValid()) {
+			KMessageBox::sorry(this, 
+			     i18n("The URL passed to KDE Battleship '%1' is not a valid url")
+			         .arg(args->arg(0)));
+			return;
+		}
+		if( u.protocol() != "kbattleship" ) {
+			KMessageBox::sorry(this, 
+			      i18n("The URL passed to KDE Battleship '%1' is not recognised "
+			           "as a Battleship game.")
+			          .arg(args->arg(0)));
+			return;
+		}
+
+		slotConnectToBattleshipServer(u.host(), u.port(), u.user());
+		
+	}
+		    
+}
+
+void KBattleshipWindow::slotConnectToBattleshipServer()
 {
-	m_kbclient = new KBattleshipClient(m_client->host(), (m_client->port()).toInt());
-	m_ownNickname = m_client->nickname();
-	m_chat->setNickname(m_ownNickname);
-	slotChangeOwnPlayer(m_ownNickname);
+	QString host = m_client->host();
+	int port = m_client->port().toInt();
+	QString nickname = m_client->nickname();
 	delete m_client;
 	m_client = 0;
+	slotConnectToBattleshipServer(host, port, nickname);
+}
+void KBattleshipWindow::slotConnectToBattleshipServer(const QString &host, int port, const QString &nickname)
+{
+	m_kbclient = new KBattleshipClient(host, port);
+	nickname.isEmpty() ? m_ownNickname = "TestUser" : m_ownNickname = nickname;
+	m_chat->setNickname(m_ownNickname);
+	slotChangeOwnPlayer(m_ownNickname);
 	cleanup(true);
 	m_aiPlaying = false;
 	m_shootable = false;
@@ -1132,17 +1159,17 @@ void KBattleshipApp::slotConnectToBattleshipServer()
 	m_kbclient->init();
 }
 
-void KBattleshipApp::slotSetPlaceable(bool place)
+void KBattleshipWindow::slotSetPlaceable(bool place)
 {
 	m_placeable = place;
 }
 
-void KBattleshipApp::slotSetShootable(bool shoot)
+void KBattleshipWindow::slotSetShootable(bool shoot)
 {
 	m_shootable = shoot;
 }
 
-void KBattleshipApp::slotShowGrid()
+void KBattleshipWindow::slotShowGrid()
 {
 	if(!m_configGrid->isChecked())
 		m_view->field()->disableGrid();
@@ -1150,31 +1177,32 @@ void KBattleshipApp::slotShowGrid()
 		m_view->field()->enableGrid();
 }
 
-void KBattleshipApp::slotStatusMsg(const QString &text)
+void KBattleshipWindow::slotStatusMsg(const QString &text)
 {
 	statusBar()->clear();
 	statusBar()->changeItem(text, ID_STATUS_MSG);
 }
 
-void KBattleshipApp::slotChangeOwnPlayer(const QString &text)
+void KBattleshipWindow::slotChangeOwnPlayer(const QString &text)
 {
 	statusBar()->clear();
 	statusBar()->changeItem(i18n("     Player 1: %1     ").arg(text), ID_PLAYER_OWN);
 }
 
-void KBattleshipApp::slotChangeEnemyPlayer(const QString &text)
+void KBattleshipWindow::slotChangeEnemyPlayer(const QString &text)
 {
 	statusBar()->clear();
 	statusBar()->changeItem(i18n("     Player 2: %1     ").arg(text), ID_PLAYER_ENEMY);
 }
 
-void KBattleshipApp::slotSinglePlayer()
+void KBattleshipWindow::slotSinglePlayer()
 {
 	bool ok;
 	if(!m_aiPlaying)
 	{
+		KUser u;
 		m_ownNickname = KInputDialog::getText(i18n("Start Game"), i18n("Nick name:"),
-			QString::fromLocal8Bit(getenv("LOGNAME")), &ok, this);
+			u.loginName(), &ok, this);
 		if (ok)
 		{
 			slotStatusMsg(i18n("Ready"));
@@ -1200,12 +1228,12 @@ void KBattleshipApp::slotSinglePlayer()
 	}
 }
 
-void KBattleshipApp::slotStartBattleshipGame()
+void KBattleshipWindow::slotStartBattleshipGame()
 {
 	slotStartBattleshipGame(true);
 }
 
-void KBattleshipApp::slotStartBattleshipGame(bool clearstat)
+void KBattleshipWindow::slotStartBattleshipGame(bool clearstat)
 {
 	m_gameSingle->setText(i18n("&Stop game"));
 	m_gameNewServer->setEnabled(false);
@@ -1235,13 +1263,13 @@ void KBattleshipApp::slotStartBattleshipGame(bool clearstat)
 	m_aiPlayer->slotRestart();
 }
 
-void KBattleshipApp::slotAIReady()
+void KBattleshipWindow::slotAIReady()
 {
 	slotStatusMsg(i18n("Please place your ships. Use the \"Shift\" key to place the ships vertically."));
 	m_placeable = true;
 }
 
-void KBattleshipApp::slotAIShootsAt(const QPoint pos)
+void KBattleshipWindow::slotAIShootsAt(const QPoint pos)
 {
 	if(!m_shootable)
 		m_shootable = true;
@@ -1277,7 +1305,7 @@ void KBattleshipApp::slotAIShootsAt(const QPoint pos)
 		m_stat->slotAddEnemyWon();
 		slotUpdateHighscore();
 		m_view->drawEnemyShipsAI(m_enemyshiplist); // let's show ai player ships
-		switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?")))
+		switch(KMessageBox::questionYesNo(this, i18n("Do you want to restart the game?"), QString::null, i18n("Restart"), i18n("Do Not Restart")))
 		{
 			case KMessageBox::Yes:
 				QTimer::singleShot(0, this, SLOT(slotRestartAI()));
@@ -1295,7 +1323,7 @@ void KBattleshipApp::slotAIShootsAt(const QPoint pos)
 	}
 }
 
-void KBattleshipApp::slotReceivedClientInformation(const QString &clientName, const QString &clientVersion, const QString &clientDescription, const QString &protocolVersion)
+void KBattleshipWindow::slotReceivedClientInformation(const QString &clientName, const QString &clientVersion, const QString &clientDescription, const QString &protocolVersion)
 {
 	m_enemyClient = clientName;
 	m_enemyClientVersion = clientVersion;
